==> okteta_0.25.5.orig.tar.xz: okteta-0.25.5/libs/kasten/core/document/documentversiondata.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DOCUMENTVERSIONDATA_H
#define DOCUMENTVERSIONDATA_H

// lib
#include <kasten/kastencore_export.h>
#include <kasten/documentversionid.h>
// Qt
#include <QString>

namespace Kasten {

class KASTENCORE_EXPORT DocumentVersionData
{
public:
    DocumentVersionData(DocumentVersionId id, const QString& changeComment);
    DocumentVersionData() = delete;

public:
    DocumentVersionId id() const;
    QString changeComment() const;

protected:
    DocumentVersionId mId;
    QString mChangeComment;
};

}

#endif

==> okteta_4.13.0.orig.tar.xz: okteta-4.13.0/libs/kasten/core/document/documentversiondata.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef DOCUMENTVERSIONDATA_H
#define DOCUMENTVERSIONDATA_H

// lib
#include "kastencore_export.h"
#include "documentversionid.h"
// Qt
#include <QtCore/QString>


namespace Kasten2
{

class KASTENCORE_EXPORT DocumentVersionData
{
  public:
    DocumentVersionData( DocumentVersionId id, const QString& changeComment );

  public:
    DocumentVersionId id() const;
    QString changeComment() const;

  protected:
    DocumentVersionId mId;
    QString mChangeComment;
};

}

#endif
